# Fashion Brands

This data was annotated by Explosion AI as part of their spaCy/Prodigy projects repo.
Find the data here: https://github.com/explosion/projects/tree/master/ner-fashion-brands

The data is included in this repo for ease of use and since it's small.
